@@ -2,9 +2,8 @@ from abc import ABC, abstractmethod
 from copy import deepcopy
 from typing import Any, Callable, Dict, Optional, Union
 
-import numpy as np
 import torch
-from torch import Tensor, eye, nn, ones, optim
+from torch import Tensor, eye, ones, optim
 from torch.nn.utils import clip_grad_norm_
 from torch.utils import data
 from torch.utils.data.sampler import SubsetRandomSampler
@@ -13,9 +12,11 @@ from torch.utils.tensorboard import SummaryWriter
 from sbi import utils as utils
 from sbi.inference.base import NeuralInference
 from sbi.inference.posteriors.ratio_based_posterior import RatioBasedPosterior
-from sbi.types import ScalarFloat
-from sbi.utils import check_estimator_arg, clamp_and_warn, x_shape_from_simulation
-from sbi.utils.torchutils import ensure_theta_batched, ensure_x_batched
+from sbi.utils import (
+    check_estimator_arg,
+    clamp_and_warn,
+    x_shape_from_simulation,
+)
 
 
 class RatioEstimator(NeuralInference, ABC):
@@ -155,6 +156,9 @@ class RatioEstimator(NeuralInference, ABC):
         # can `sample()` and `log_prob()`. The network is accessible via `.net`.
         if self._posterior is None or retrain_from_scratch_each_round:
             x_shape = x_shape_from_simulation(x)
+            assert (
+                len(x_shape) < 3
+            ), "For now, SNRE cannot handle multi-dimensional simulator output, see issue #360."
             self._posterior = RatioBasedPosterior(
                 method_family=self.__class__.__name__.lower(),
                 neural_net=self._build_neural_net(theta, x),
