@@ -2,7 +2,19 @@
 # under the Affero General Public License v3, see <https://www.gnu.org/licenses/>.
 
 
-from typing import Callable, Optional, Union, Dict, Any, Tuple, Union, cast, List, Sequence, TypeVar
+from typing import (
+    Callable,
+    Optional,
+    Union,
+    Dict,
+    Any,
+    Tuple,
+    Union,
+    cast,
+    List,
+    Sequence,
+    TypeVar,
+)
 
 import torch
 from torch import Tensor
@@ -39,7 +51,6 @@ def simulate_in_batches(
     num_sims, *_ = theta.shape
 
     if num_sims == 0:
-        logging.warning("Zero-length parameter theta implies zero simulations.")
         x = torch.tensor([])
     elif sim_batch_size is not None and sim_batch_size < num_sims:
         # Dev note: pyright complains of torch.split lacking a type stub
