@@ -1,5 +1,8 @@
 # flake8: noqa
-from sbi.user_input.user_input_checks import check_estimator_arg
+from sbi.user_input.user_input_checks import (
+    check_estimator_arg,
+    test_posterior_net_for_multi_d_x,
+)
 from sbi.user_input.user_input_checks_utils import MultipleIndependent
 from sbi.utils.get_nn_models import classifier_nn, likelihood_nn, posterior_nn
 from sbi.utils.io import get_data_root, get_log_root, get_project_root
